==> wiki3_5_1.zip: wiki3_5_1/plugin/attach/AdminMIMEHandler.pm <==
###############################################################################
#
# MIMEפԤϥɥ
#
###############################################################################
package plugin::attach::AdminMIMEHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	
	$wiki->set_title("MIMEפ");
	
	if($cgi->param("ADD") ne ""){
		return $self->add($wiki);
		
	} elsif($cgi->param("DELETE") ne ""){
		return $self->delete($wiki);
		
	} else {
		return $self->form($wiki);
	}
}

#==============================================================================
# 
#==============================================================================
sub form {
	my $self = shift;
	my $wiki = shift;
	my $buf = "<h2>MIMEפϿ</h2>\n".
	          "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "  ĥҡʥɥåȤס <input type=\"text\" name=\"extention\" size=\"5\">\n".
	          "  MIME <input type=\"text\" name=\"mimetype\" size=\"20\">\n".
	          "  <input type=\"submit\" name=\"ADD\" value=\"Ͽ\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"ADMINMIME\">\n".
	          "</form>\n".
	          "<h2>ϿѤMIME</h2>\n".
	          "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "<table>\n".
	          "<tr><th>&nbsp;</td><th>ĥ</th><th>MIME</th></tr>\n";
	
	my $mime = &Util::load_config_hash($wiki,"mime.dat");
	
	foreach my $key (sort(keys(%$mime))){
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"extention\" value=\"".&Util::escapeHTML($key)."\"></td>\n".
		        "  <td>".&Util::escapeHTML($key)."</td>\n".
		        "  <td>".&Util::escapeHTML($mime->{$key})."</td>\n".
		        "</tr>\n";
	}
	$buf .= "</table><br>\n".
	        "<input type=\"submit\" name=\"DELETE\" value=\"ܤ\">\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINMIME\">\n".
	        "</form>\n";
	
	return $buf;
}

#==============================================================================
# ɲ
#==============================================================================
sub add {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	
	my $ext  = $cgi->param("extention");
	my $mime = $cgi->param("mimetype");
	
	if($ext ne "" && $mime ne ""){
		my $hash = &Util::load_config_hash($wiki,"mime.dat");
		$hash->{$ext} = $mime;
		&Util::save_config_hash($wiki,"mime.dat",$hash);
		return $self->form($wiki);
		
	} else {
		return $wiki->error("ĥҤMIMEפϤƤ");
	}
}

#==============================================================================
# 
#==============================================================================
sub delete {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	
	my @ext_list = $cgi->param("extention");
	my $hash     = &Util::load_config_hash($wiki,"mime.dat");
	my $result   = {};
	
	foreach my $key (keys(%$hash)){
		my $flag = 0;
		foreach my $ext (@ext_list){
			if($ext eq $key){
				$flag = 1;
				last;
			}
		}
		if($flag==0){
			$result->{$key} = $hash->{$key};
		}
	}
	
	&Util::save_config_hash($wiki,"mime.dat",$result);
	
	return $self->form($wiki);
}

1;

==> wiki3_5_7dev2.zip: wiki3_5_7dev2/plugin/attach/AdminMIMEHandler.pm <==
###############################################################################
#
# MIMEפԤϥɥ
#
###############################################################################
package plugin::attach::AdminMIMEHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	
	$wiki->set_title("MIMEפ");
	
	if($cgi->param("ADD") ne ""){
		return $self->add($wiki);
		
	} elsif($cgi->param("DELETE") ne ""){
		return $self->delete($wiki);
		
	} else {
		return $self->form($wiki);
	}
}

#==============================================================================
# 
#==============================================================================
sub form {
	my $self = shift;
	my $wiki = shift;
	my $buf = "<h2>MIMEפϿ</h2>\n".
	          "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "  ĥҡʥɥåȤס <input type=\"text\" name=\"extention\" size=\"5\">\n".
	          "  MIME <input type=\"text\" name=\"mimetype\" size=\"20\">\n".
	          "  <input type=\"submit\" name=\"ADD\" value=\"Ͽ\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"ADMINMIME\">\n".
	          "</form>\n".
	          "<h2>ϿѤMIME</h2>\n".
	          "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "<table>\n".
	          "<tr><th>&nbsp;</td><th>ĥ</th><th>MIME</th></tr>\n";
	
	my $mime = &Util::load_config_hash($wiki,"mime.dat");
	
	foreach my $key (sort(keys(%$mime))){
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"extention\" value=\"".&Util::escapeHTML($key)."\"></td>\n".
		        "  <td>".&Util::escapeHTML($key)."</td>\n".
		        "  <td>".&Util::escapeHTML($mime->{$key})."</td>\n".
		        "</tr>\n";
	}
	$buf .= "</table>\n".
	        "<input type=\"submit\" name=\"DELETE\" value=\"ܤ\">\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINMIME\">\n".
	        "</form>\n";
	
	return $buf;
}

#==============================================================================
# ɲ
#==============================================================================
sub add {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	
	my $ext  = $cgi->param("extention");
	my $mime = $cgi->param("mimetype");
	
	if($ext ne "" && $mime ne ""){
		my $hash = &Util::load_config_hash($wiki,"mime.dat");
		$hash->{$ext} = $mime;
		&Util::save_config_hash($wiki,"mime.dat",$hash);
		$wiki->redirectURL($wiki->config('script_name')."?action=ADMINMIME");
		#return $self->form($wiki);
		
	} else {
		return $wiki->error("ĥҤMIMEפϤƤ");
	}
}

#==============================================================================
# 
#==============================================================================
sub delete {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	
	my @ext_list = $cgi->param("extention");
	my $hash     = &Util::load_config_hash($wiki,"mime.dat");
	my $result   = {};
	
	foreach my $key (keys(%$hash)){
		my $flag = 0;
		foreach my $ext (@ext_list){
			if($ext eq $key){
				$flag = 1;
				last;
			}
		}
		if($flag==0){
			$result->{$key} = $hash->{$key};
		}
	}
	
	&Util::save_config_hash($wiki,"mime.dat",$result);
	$wiki->redirectURL($wiki->config('script_name')."?action=ADMINMIME");
	
	#return $self->form($wiki);
}

1;
